@@ -21,6 +21,7 @@
 #ifndef KATE_PROJECT_H
 #define KATE_PROJECT_H
 
+#include <QDateTime>
 #include <QMap>
 #include <QSharedPointer>
 #include <QTextDocument>
@@ -97,6 +98,12 @@ public:
         return m_baseDir;
     }
 
+    /**
+     * Return the time when the project file has been modified last.
+     * @return QFileInfo::lastModified()
+     */
+    QDateTime fileLastModified() const { return m_fileLastModified; }
+
     /**
      * Accessor to project map containing the whole project info.
      * @return project info
@@ -227,6 +234,12 @@ private:
     void unregisterUntrackedItem(const KateProjectItem *item);
 
 private:
+
+    /**
+     * Last modification time of the project file
+     */
+    QDateTime m_fileLastModified;
+
     /**
      * project file name
      */
