@@ -89,7 +89,7 @@ public:
     TreeWidgetItem(QTreeWidget* parent, const QStringList &list):QTreeWidgetItem(parent, list){}
     TreeWidgetItem(QTreeWidgetItem* parent, const QStringList &list):QTreeWidgetItem(parent, list){}
 private:
-    bool operator<(const QTreeWidgetItem &other)const {
+    bool operator<(const QTreeWidgetItem &other) const Q_DECL_OVERRIDE {
         if (childCount() == 0) {
             int line = data(0, ReplaceMatches::LineRole).toInt();
             int column = data(0, ReplaceMatches::ColumnRole).toInt();
@@ -125,9 +125,6 @@ KatePluginSearch::KatePluginSearch(QObject* parent, const QList<QVariant>&)
     : KTextEditor::Plugin (parent),
     m_searchCommand(0)
 {
-    // FIXME KF5
-    //KGlobal::locale()->insertCatalog("katesearch");
-
     m_searchCommand = new KateSearchCommand(this);
 }
 
@@ -494,13 +491,18 @@ void KatePluginSearchView::handleEsc(QEvent *e)
 
     QKeyEvent *k = static_cast<QKeyEvent *>(e);
     if (k->key() == Qt::Key_Escape && k->modifiers() == Qt::NoModifier) {
-
-        if (m_toolView->isVisible()) {
-            m_mainWindow->hideToolView(m_toolView);
+        static ulong lastTimeStamp;
+        if (lastTimeStamp == k->timestamp()) {
+            // Same as previous... This looks like a bug somewhere...
+            return;
         }
-        else {
+        lastTimeStamp = k->timestamp();
+        if (!m_matchRanges.isEmpty()) {
             clearMarks();
         }
+        else if (m_toolView->isVisible()) {
+            m_mainWindow->hideToolView(m_toolView);
+        }
     }
 }
 
@@ -590,7 +592,7 @@ void KatePluginSearchView::folderFileListChanged()
 
     QList<KTextEditor::Document*> openList;
     for (int i=0; i<m_kateApp->documents().size(); i++) {
-        int index = fileList.indexOf(m_kateApp->documents()[i]->url().toString());
+        int index = fileList.indexOf(m_kateApp->documents()[i]->url().toLocalFile());
         if (index != -1) {
             openList << m_kateApp->documents()[i];
             fileList.removeAt(index);
@@ -616,11 +618,12 @@ void KatePluginSearchView::searchPlaceChanged()
     m_ui.displayOptions->setChecked(true);
 
     const bool inFolder = (m_ui.searchPlaceCombo->currentIndex() == 1);
-    const bool inProject = (m_ui.searchPlaceCombo->currentIndex() == 2);
+    const bool inCurrentProject = (m_ui.searchPlaceCombo->currentIndex() == 2);
+    const bool inAllOpenProjects = (m_ui.searchPlaceCombo->currentIndex() == 3);
 
-    m_ui.filterCombo->setEnabled(inFolder || inProject);
+    m_ui.filterCombo->setEnabled(inFolder || inCurrentProject || inAllOpenProjects);
 
-    m_ui.excludeCombo->setEnabled(inFolder || inProject);
+    m_ui.excludeCombo->setEnabled(inFolder || inCurrentProject || inAllOpenProjects);
     m_ui.folderRequester->setEnabled(inFolder);
     m_ui.folderUpButton->setEnabled(inFolder);
     m_ui.currentFolderButton->setEnabled(inFolder);
@@ -649,11 +652,13 @@ QTreeWidgetItem * KatePluginSearchView::rootFileItem(const QString &url, const Q
         return 0;
     }
 
-    // FIXME KF5
-    QUrl kurl = QUrl::fromUserInput(url);
-    QString path = kurl.isLocalFile() ? localFileDirUp (kurl).path() : kurl.url();
+    QUrl fullUrl = QUrl::fromUserInput(url);
+    QString path = fullUrl.isLocalFile() ? localFileDirUp (fullUrl).path() : fullUrl.url();
+    if (!path.isEmpty() && !path.endsWith(QLatin1Char('/'))) {
+        path += QLatin1Char('/');
+    }
     path.replace(m_resultBaseDir, QString());
-    QString name = kurl.fileName();
+    QString name = fullUrl.fileName();
     if (url.isEmpty()) {
         name = fName;
     }
@@ -903,6 +908,9 @@ void KatePluginSearchView::startSearch()
     m_searchDiskFilesDone = false;
     m_searchOpenFilesDone = false;
 
+    const bool inCurrentProject = m_ui.searchPlaceCombo->currentIndex() == 2;
+    const bool inAllOpenProjects = m_ui.searchPlaceCombo->currentIndex() == 3;
+
     if (m_ui.searchPlaceCombo->currentIndex() ==  0) {
         m_searchDiskFilesDone = true;
         m_resultBaseDir.clear();
@@ -911,7 +919,9 @@ void KatePluginSearchView::startSearch()
         m_searchOpenFiles.startSearch(documents, reg);
     }
     else if (m_ui.searchPlaceCombo->currentIndex() == 1) {
-        m_resultBaseDir = m_ui.folderRequester->text();
+        m_resultBaseDir = m_ui.folderRequester->url().path();
+        if (!m_resultBaseDir.isEmpty() && !m_resultBaseDir.endsWith(QLatin1Char('/')))
+            m_resultBaseDir += QLatin1Char('/');
         addHeaderItem();
         m_folderFilesList.generateList(m_ui.folderRequester->text(),
                                        m_ui.recursiveCheckBox->isChecked(),
@@ -922,19 +932,29 @@ void KatePluginSearchView::startSearch()
                                        m_ui.excludeCombo->currentText());
         // the file list will be ready when the thread returns (connected to folderFileListChanged)
     }
-    else {
+    else if (inCurrentProject || inAllOpenProjects) {
         /**
          * init search with file list from current project, if any
          */
         m_resultBaseDir.clear();
         QStringList files;
-        QString projectName;
         if (m_projectPluginView) {
-            projectName = m_projectPluginView->property ("projectName").toString();
-            m_resultBaseDir = m_projectPluginView->property ("projectBaseDir").toString();
+            if (inCurrentProject) {
+                m_resultBaseDir = m_projectPluginView->property ("projectBaseDir").toString();
+            } else {
+                m_resultBaseDir = m_projectPluginView->property ("allProjectsCommonBaseDir").toString();
+            }
+
             if (!m_resultBaseDir.endsWith(QLatin1Char('/')))
                 m_resultBaseDir += QLatin1Char('/');
-            QStringList projectFiles = m_projectPluginView->property ("projectFiles").toStringList();
+
+            QStringList projectFiles;
+            if (inCurrentProject) {
+                projectFiles = m_projectPluginView->property ("projectFiles").toStringList();
+            } else {
+                projectFiles = m_projectPluginView->property ("allProjectsFiles").toStringList();
+            }
+
             files = filterFiles(projectFiles);
         }
         addHeaderItem();
@@ -952,11 +972,12 @@ void KatePluginSearchView::startSearch()
         // The DiskFile might finish immediately
         if (openList.size() > 0) {
             m_searchOpenFiles.startSearch(openList, m_curResults->regExp);
-        }
-        else {
+        } else {
             m_searchOpenFilesDone = true;
         }
         m_searchDiskFiles.startSearch(files, reg);
+    } else {
+        Q_ASSERT_X(false, "KatePluginSearchView::startSearch", "case not handled");
     }
 }
 
@@ -1075,14 +1096,22 @@ void KatePluginSearchView::searchDone()
                                                         m_resultBaseDir));
                 break;
             case 2:
-                QString projectName;
-                if (m_projectPluginView) {
-                    projectName = m_projectPluginView->property("projectName").toString();
+                {
+                    QString projectName;
+                    if (m_projectPluginView) {
+                        projectName = m_projectPluginView->property("projectName").toString();
+                    }
+                    root->setData(0, Qt::DisplayRole, i18np("<b><i>One match found in project %2 (%3)</i></b>",
+                                                            "<b><i>%1 matches found in project %2 (%3)</i></b>",
+                                                            m_curResults->matches,
+                                                            projectName,
+                                                            m_resultBaseDir));
+                    break;
                 }
-                root->setData(0, Qt::DisplayRole, i18np("<b><i>One match found in project %2 (%3)</i></b>",
-                                                        "<b><i>%1 matches found in project %2 (%3)</i></b>",
+            case 3: // "in Open Projects"
+                root->setData(0, Qt::DisplayRole, i18np("<b><i>One match found in all open projects (common parent: %2)</i></b>",
+                                                        "<b><i>%1 matches found in all open projects (common parent: %2)</i></b>",
                                                         m_curResults->matches,
-                                                        projectName,
                                                         m_resultBaseDir));
                 break;
         }
@@ -1466,10 +1495,10 @@ void KatePluginSearchView::goToPreviousMatch()
 void KatePluginSearchView::readSessionConfig(const KConfigGroup &cg)
 {
     m_ui.searchCombo->clear();
-    m_ui.searchCombo->addItem(QStringLiteral()); // Add empty Item
+    m_ui.searchCombo->addItem(QString()); // Add empty Item
     m_ui.searchCombo->addItems(cg.readEntry("Search", QStringList()));
     m_ui.replaceCombo->clear();
-    m_ui.replaceCombo->addItem(QStringLiteral()); // Add empty Item
+    m_ui.replaceCombo->addItem(QString()); // Add empty Item
     m_ui.replaceCombo->addItems(cg.readEntry("Replaces", QStringList()));
     m_ui.matchCase->setChecked(cg.readEntry("MatchCase", false));
     m_ui.useRegExp->setChecked(cg.readEntry("UseRegExp", false));
@@ -1646,11 +1675,7 @@ bool KatePluginSearchView::eventFilter(QObject *obj, QEvent *event)
                 }
             }
         }
-        if ((obj == m_toolView) && (ke->key() == Qt::Key_Escape)) {
-            m_mainWindow->hideToolView(m_toolView);
-            event->accept();
-            return true;
-        }
+        // NOTE: Qt::Key_Escape is handeled by handleEsc
     }
     return QObject::eventFilter(obj, event);
 }
@@ -1743,12 +1768,15 @@ void KatePluginSearchView::slotProjectFileNameChanged ()
     if (!projectFileName.isEmpty()) {
         if (m_ui.searchPlaceCombo->count() < 3) {
             // add "in Project"
-            m_ui.searchPlaceCombo->addItem (SmallIcon(QStringLiteral("project-open")), i18n("in Project"));
+            m_ui.searchPlaceCombo->addItem (SmallIcon(QStringLiteral("project-open")), i18n("Current Project"));
             if (m_switchToProjectModeWhenAvailable) {
                 // switch to search "in Project"
                 m_switchToProjectModeWhenAvailable = false;
                 setSearchPlace (2);
             }
+
+            // add "in Open Projects"
+            m_ui.searchPlaceCombo->addItem(SmallIcon(QStringLiteral("project-open")), i18n("All Open Projects"));
         }
     }
 
